[open-ils-commits] [GIT] Evergreen ILS branch master updated. 4d202fcc96ebdcd58364850d429142c386bd0c8f

Evergreen Git git at git.evergreen-ils.org
Tue Sep 19 20:29:48 EDT 2017


This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "Evergreen ILS".

The branch, master has been updated
       via  4d202fcc96ebdcd58364850d429142c386bd0c8f (commit)
       via  3195aace7a6e7e094619fcc11684f508e2f65661 (commit)
      from  ad11d47214f7c565140de6aae4893ddc3d1925c6 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -----------------------------------------------------------------
commit 4d202fcc96ebdcd58364850d429142c386bd0c8f
Author: Galen Charlton <gmc at equinoxinitiative.org>
Date:   Tue Sep 19 20:45:20 2017 -0400

    LP#1706124: minor tweaks
    
    - change name of setting to better match local convention
    - adjust whitespace
    
    Signed-off-by: Galen Charlton <gmc at equinoxinitiative.org>

diff --git a/Open-ILS/web/js/ui/default/staff/services/patron_search.js b/Open-ILS/web/js/ui/default/staff/services/patron_search.js
index 7897671..758681a 100644
--- a/Open-ILS/web/js/ui/default/staff/services/patron_search.js
+++ b/Open-ILS/web/js/ui/default/staff/services/patron_search.js
@@ -745,17 +745,17 @@ function($scope,  $q,  $routeParams,  $timeout,  $window,  $location,  egCore,
     egCore.hatch.getItem('eg.circ.patron.search.show_extras')
     .then(function(val) {$scope.showExtras = val});
 
-// check searchArgs.inactive setting
-    egCore.hatch.getItem('searchArgs.inactive')
+    // check searchArgs.inactive setting
+    egCore.hatch.getItem('eg.circ.patron.search.include_inactive')
                 .then(function(searchInactive){
-                    if (searchInactive) $scope.searchArgs.inactive = searchInactive; 
-                });    
+                    if (searchInactive) $scope.searchArgs.inactive = searchInactive;
+                });
 
-     $scope.onSearchInactiveChanged = function(){
-        egCore.hatch.setItem('searchArgs.inactive', $scope.searchArgs.inactive);
+     $scope.onSearchInactiveChanged = function() {
+        egCore.hatch.setItem('eg.circ.patron.search.include_inactive', $scope.searchArgs.inactive);
     }
 
-// map form arguments into search params
+    // map form arguments into search params
     function compileSearch(args) {
         var search = {};
         angular.forEach(args, function(val, key) {

commit 3195aace7a6e7e094619fcc11684f508e2f65661
Author: Kathy Lussier <klussier at masslnc.org>
Date:   Wed Sep 13 13:07:29 2017 -0400

    LP#1706124: Make include inactive patrons checkbox sticky
    
    The state of the 'include inactive' checkbox on the patron search page will now
    be remembered when users return to the page. Many thanks to Cesar Velez,
    whose code for bug 1697754 inspired this patch!
    
    Signed-off-by: Kathy Lussier <klussier at masslnc.org>
    Signed-off-by: Jason Stephenson <jason at sigio.com>
    Signed-off-by: Galen Charlton <gmc at equinoxinitiative.org>

diff --git a/Open-ILS/src/templates/staff/share/t_patron_search_form.tt2 b/Open-ILS/src/templates/staff/share/t_patron_search_form.tt2
index 816076c..d84a2f8 100644
--- a/Open-ILS/src/templates/staff/share/t_patron_search_form.tt2
+++ b/Open-ILS/src/templates/staff/share/t_patron_search_form.tt2
@@ -139,7 +139,7 @@
         <div class="col-md-2">
           <div class="checkbox">
             <label>
-              <input type="checkbox" ng-model="searchArgs.inactive"/>
+              <input type="checkbox" ng-model="searchArgs.inactive" ng-change="onSearchInactiveChanged()"/>
               [% l('Include Inactive?') %]
             </label>
           </div>
diff --git a/Open-ILS/web/js/ui/default/staff/services/patron_search.js b/Open-ILS/web/js/ui/default/staff/services/patron_search.js
index c27274f..7897671 100644
--- a/Open-ILS/web/js/ui/default/staff/services/patron_search.js
+++ b/Open-ILS/web/js/ui/default/staff/services/patron_search.js
@@ -745,7 +745,17 @@ function($scope,  $q,  $routeParams,  $timeout,  $window,  $location,  egCore,
     egCore.hatch.getItem('eg.circ.patron.search.show_extras')
     .then(function(val) {$scope.showExtras = val});
 
-    // map form arguments into search params
+// check searchArgs.inactive setting
+    egCore.hatch.getItem('searchArgs.inactive')
+                .then(function(searchInactive){
+                    if (searchInactive) $scope.searchArgs.inactive = searchInactive; 
+                });    
+
+     $scope.onSearchInactiveChanged = function(){
+        egCore.hatch.setItem('searchArgs.inactive', $scope.searchArgs.inactive);
+    }
+
+// map form arguments into search params
     function compileSearch(args) {
         var search = {};
         angular.forEach(args, function(val, key) {

-----------------------------------------------------------------------

Summary of changes:
 .../templates/staff/share/t_patron_search_form.tt2 |    2 +-
 .../js/ui/default/staff/services/patron_search.js  |   10 ++++++++++
 2 files changed, 11 insertions(+), 1 deletions(-)


hooks/post-receive
-- 
Evergreen ILS


More information about the open-ils-commits mailing list